"use client";

import Image from "next/image";
import * as React from "react";

import useEmblaCarousel from "embla-carousel-react";

import { ContentLines } from "@/components/shared/content-lines";
import { Button } from "@/components/ui/button";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { fetchProjects } from "@/servers/actions/project-action";
import { TestimonialData } from "@/utils/get-fake-data";
import { useQuery } from "@tanstack/react-query";

interface TestimonialClientProps {
	data: TestimonialData;
	locale: Locale;
}

export default function TestimonialClient({
	data,
	locale,
}: TestimonialClientProps) {
	const isRTL = locale === "ar";
	const [activeIndex, setActiveIndex] = React.useState(0);

	const [emblaRef, emblaApi] = useEmblaCarousel({
		align: "start",
		loop: true,
	});

	React.useEffect(() => {
		if (emblaApi) {
			emblaApi.on("select", () => {
				setActiveIndex(emblaApi.selectedScrollSnap());
			});
		}
	}, [emblaApi]);


	const { data: projects } = useQuery({
		queryKey: ["project"],
		queryFn: () => fetchProjects(),
	});


	return (
		<section className="overflow-hidden">
			<div className="container relative mx-auto max-w-7xl px-4 py-8 sm:py-12 lg:px-8">
				<div className="grid grid-cols-1 gap-8 lg:grid-cols-12">
					{/* Content */}
					<div
						className={cn(
							"flex flex-col justify-between rounded-lg border-gray-300 bg-custom-background-light p-6 shadow-[0_78px_34px_-45px_rgba(0,0,0,0.15)]",
							"lg:col-span-6 lg:h-[403px]"
						)}
					>
						{/* Section Header */}
						<div className={cn("mb-6 flex flex-col")}>
							<ContentLines
								className="pb-4 sm:pb-6"
								padding="none"
								title={data.section.subtitle?.[locale]}
								underlineColor="custom-primary-accent"
								textColor="text-custom-primary-accent"
							/>
							<h2 className="text-2xl font-bold text-custom-dark-veryDark sm:text-3xl lg:text-4xl">
								{data.section.title?.[locale]}
							</h2>
						</div>
						<p
							className={cn(
								"mb-6 leading-relaxed text-custom-dark-light",
								isRTL ? "text-right" : "text-left"
							)}
						>
							{data.testimonials[activeIndex].content?.[locale]}
						</p>
						<Button className="h-12 w-full rounded-xl bg-custom-secondary px-6 text-white hover:bg-custom-secondary/90 sm:h-[50px] sm:w-[125px]">
							{data.section.allClients?.[locale]}
						</Button>
					</div>

					{/* Main image with slider */}
					<div className="relative lg:col-span-6">
						<div className="overflow-hidden" ref={emblaRef}>
							<div className="flex">
								{data.testimonials?.map((testimonial) => (
									<div
										key={testimonial.id}
										className="relative mr-4 min-w-0 flex-[0_0_100%]"
									>
										<div className="relative mx-auto aspect-square w-full max-w-[403px]">
											<Image
												src={testimonial.client.logo}
												alt={testimonial.client.name?.[locale]}
												fill
												className="rounded-lg object-contain p-4 sm:p-8 shadow-[0_78px_34px_-45px_rgba(0,0,0,0.15)]"
											/>
										</div>
									</div>
								))}
							</div>
						</div>
						<div className="absolute bottom-4 left-1/2 z-20 flex -translate-x-1/2 transform space-x-2">
							{data.testimonials?.map((_, index) => (
								<button
									key={index}
									className={cn(
										"h-2 w-2 rounded-full transition-colors sm:h-3 sm:w-3",
										index === activeIndex
											? "bg-blue-500"
											: "bg-gray-300 hover:bg-gray-400"
									)}
									onClick={() => emblaApi?.scrollTo(index)}
									aria-label={`View testimonial ${index + 1}`}
								/>
							))}
						</div>
					</div>

					{/* Wave Background */}
					<div className="pointer-events-none absolute inset-0 z-0 overflow-hidden">
						<div className="absolute bottom-0 right-8 h-1/3 w-2/3 lg:h-2/3 lg:w-full">
							<Image
								src={data.images.wave}
								alt="Wave background"
								fill
								quality={100}
								className="object-cover object-right-bottom"
								style={{
									maskImage:
										"linear-gradient(to left, rgba(0,0,0,1), rgba(0,0,0,0))",
									WebkitMaskImage:
										"linear-gradient(to left, rgba(0,0,0,1), rgba(0,0,0,0))",
								}}
							/>
						</div>
					</div>
				</div>
			</div>
		</section>
	);
}
